"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DataprocAutoscalingPolicyXBasicAlgorithmXYarnConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRACEFUL_DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    SCALE_DOWN_FACTOR_FIELD_NUMBER: builtins.int
    SCALE_DOWN_MIN_WORKER_FRACTION_FIELD_NUMBER: builtins.int
    SCALE_UP_FACTOR_FIELD_NUMBER: builtins.int
    SCALE_UP_MIN_WORKER_FRACTION_FIELD_NUMBER: builtins.int
    graceful_decommission_timeout: builtins.str
    scale_down_factor: builtins.float
    scale_down_min_worker_fraction: builtins.float
    scale_up_factor: builtins.float
    scale_up_min_worker_fraction: builtins.float
    def __init__(
        self,
        *,
        graceful_decommission_timeout: builtins.str = ...,
        scale_down_factor: builtins.float = ...,
        scale_down_min_worker_fraction: builtins.float = ...,
        scale_up_factor: builtins.float = ...,
        scale_up_min_worker_fraction: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["graceful_decommission_timeout", b"graceful_decommission_timeout", "scale_down_factor", b"scale_down_factor", "scale_down_min_worker_fraction", b"scale_down_min_worker_fraction", "scale_up_factor", b"scale_up_factor", "scale_up_min_worker_fraction", b"scale_up_min_worker_fraction"]) -> None: ...

global___DataprocAutoscalingPolicyXBasicAlgorithmXYarnConfig = DataprocAutoscalingPolicyXBasicAlgorithmXYarnConfig

@typing_extensions.final
class DataprocAutoscalingPolicyXBasicAlgorithm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COOLDOWN_PERIOD_FIELD_NUMBER: builtins.int
    YARN_CONFIG_FIELD_NUMBER: builtins.int
    cooldown_period: builtins.str
    @property
    def yarn_config(self) -> global___DataprocAutoscalingPolicyXBasicAlgorithmXYarnConfig: ...
    def __init__(
        self,
        *,
        cooldown_period: builtins.str = ...,
        yarn_config: global___DataprocAutoscalingPolicyXBasicAlgorithmXYarnConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["yarn_config", b"yarn_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cooldown_period", b"cooldown_period", "yarn_config", b"yarn_config"]) -> None: ...

global___DataprocAutoscalingPolicyXBasicAlgorithm = DataprocAutoscalingPolicyXBasicAlgorithm

@typing_extensions.final
class DataprocAutoscalingPolicyXSecondaryWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_INSTANCES_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    max_instances: builtins.float
    min_instances: builtins.float
    weight: builtins.float
    def __init__(
        self,
        *,
        max_instances: builtins.float = ...,
        min_instances: builtins.float = ...,
        weight: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_instances", b"max_instances", "min_instances", b"min_instances", "weight", b"weight"]) -> None: ...

global___DataprocAutoscalingPolicyXSecondaryWorkerConfig = DataprocAutoscalingPolicyXSecondaryWorkerConfig

@typing_extensions.final
class DataprocAutoscalingPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataprocAutoscalingPolicyXTimeouts = DataprocAutoscalingPolicyXTimeouts

@typing_extensions.final
class DataprocAutoscalingPolicyXWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_INSTANCES_FIELD_NUMBER: builtins.int
    MIN_INSTANCES_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    max_instances: builtins.float
    min_instances: builtins.float
    weight: builtins.float
    def __init__(
        self,
        *,
        max_instances: builtins.float = ...,
        min_instances: builtins.float = ...,
        weight: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_instances", b"max_instances", "min_instances", b"min_instances", "weight", b"weight"]) -> None: ...

global___DataprocAutoscalingPolicyXWorkerConfig = DataprocAutoscalingPolicyXWorkerConfig

@typing_extensions.final
class DataprocAutoscalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    BASIC_ALGORITHM_FIELD_NUMBER: builtins.int
    SECONDARY_WORKER_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    location: builtins.str
    name: builtins.str
    policy_id: builtins.str
    project: builtins.str
    @property
    def basic_algorithm(self) -> global___DataprocAutoscalingPolicyXBasicAlgorithm: ...
    @property
    def secondary_worker_config(self) -> global___DataprocAutoscalingPolicyXSecondaryWorkerConfig: ...
    @property
    def timeouts(self) -> global___DataprocAutoscalingPolicyXTimeouts: ...
    @property
    def worker_config(self) -> global___DataprocAutoscalingPolicyXWorkerConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        policy_id: builtins.str = ...,
        project: builtins.str = ...,
        basic_algorithm: global___DataprocAutoscalingPolicyXBasicAlgorithm | None = ...,
        secondary_worker_config: global___DataprocAutoscalingPolicyXSecondaryWorkerConfig | None = ...,
        timeouts: global___DataprocAutoscalingPolicyXTimeouts | None = ...,
        worker_config: global___DataprocAutoscalingPolicyXWorkerConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["basic_algorithm", b"basic_algorithm", "resource_info", b"resource_info", "secondary_worker_config", b"secondary_worker_config", "timeouts", b"timeouts", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["basic_algorithm", b"basic_algorithm", "id", b"id", "location", b"location", "name", b"name", "policy_id", b"policy_id", "project", b"project", "resource_info", b"resource_info", "secondary_worker_config", b"secondary_worker_config", "timeouts", b"timeouts", "worker_config", b"worker_config"]) -> None: ...

global___DataprocAutoscalingPolicy = DataprocAutoscalingPolicy

@typing_extensions.final
class DataprocAutoscalingPolicyIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocAutoscalingPolicyIamBindingXCondition = DataprocAutoscalingPolicyIamBindingXCondition

@typing_extensions.final
class DataprocAutoscalingPolicyIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    policy_id: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataprocAutoscalingPolicyIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        policy_id: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataprocAutoscalingPolicyIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "policy_id", b"policy_id", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataprocAutoscalingPolicyIamBinding = DataprocAutoscalingPolicyIamBinding

@typing_extensions.final
class DataprocAutoscalingPolicyIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocAutoscalingPolicyIamMemberXCondition = DataprocAutoscalingPolicyIamMemberXCondition

@typing_extensions.final
class DataprocAutoscalingPolicyIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    policy_id: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataprocAutoscalingPolicyIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        policy_id: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataprocAutoscalingPolicyIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "policy_id", b"policy_id", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataprocAutoscalingPolicyIamMember = DataprocAutoscalingPolicyIamMember

@typing_extensions.final
class DataprocAutoscalingPolicyIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    policy_id: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        policy_id: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "policy_id", b"policy_id", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___DataprocAutoscalingPolicyIamPolicy = DataprocAutoscalingPolicyIamPolicy

@typing_extensions.final
class DataprocClusterXClusterConfigXAutoscalingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_URI_FIELD_NUMBER: builtins.int
    policy_uri: builtins.str
    def __init__(
        self,
        *,
        policy_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy_uri", b"policy_uri"]) -> None: ...

global___DataprocClusterXClusterConfigXAutoscalingConfig = DataprocClusterXClusterConfigXAutoscalingConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name"]) -> None: ...

global___DataprocClusterXClusterConfigXEncryptionConfig = DataprocClusterXClusterConfigXEncryptionConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXEndpointConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HttpPortsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENABLE_HTTP_PORT_ACCESS_FIELD_NUMBER: builtins.int
    HTTP_PORTS_FIELD_NUMBER: builtins.int
    enable_http_port_access: builtins.bool
    @property
    def http_ports(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        enable_http_port_access: builtins.bool = ...,
        http_ports: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_http_port_access", b"enable_http_port_access", "http_ports", b"http_ports"]) -> None: ...

global___DataprocClusterXClusterConfigXEndpointConfig = DataprocClusterXClusterConfigXEndpointConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXGceClusterConfigXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___DataprocClusterXClusterConfigXGceClusterConfigXShieldedInstanceConfig = DataprocClusterXClusterConfigXGceClusterConfigXShieldedInstanceConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXGceClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    INTERNAL_IP_ONLY_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_SCOPES_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    internal_ip_only: builtins.bool
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    network: builtins.str
    service_account: builtins.str
    @property
    def service_account_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    subnetwork: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    @property
    def shielded_instance_config(self) -> global___DataprocClusterXClusterConfigXGceClusterConfigXShieldedInstanceConfig: ...
    def __init__(
        self,
        *,
        internal_ip_only: builtins.bool = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network: builtins.str = ...,
        service_account: builtins.str = ...,
        service_account_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        subnetwork: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
        shielded_instance_config: global___DataprocClusterXClusterConfigXGceClusterConfigXShieldedInstanceConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shielded_instance_config", b"shielded_instance_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["internal_ip_only", b"internal_ip_only", "metadata", b"metadata", "network", b"network", "service_account", b"service_account", "service_account_scopes", b"service_account_scopes", "shielded_instance_config", b"shielded_instance_config", "subnetwork", b"subnetwork", "tags", b"tags", "zone", b"zone"]) -> None: ...

global___DataprocClusterXClusterConfigXGceClusterConfig = DataprocClusterXClusterConfigXGceClusterConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXInitializationAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCRIPT_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    script: builtins.str
    timeout_sec: builtins.float
    def __init__(
        self,
        *,
        script: builtins.str = ...,
        timeout_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["script", b"script", "timeout_sec", b"timeout_sec"]) -> None: ...

global___DataprocClusterXClusterConfigXInitializationAction = DataprocClusterXClusterConfigXInitializationAction

@typing_extensions.final
class DataprocClusterXClusterConfigXLifecycleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_DELETE_TIME_FIELD_NUMBER: builtins.int
    IDLE_DELETE_TTL_FIELD_NUMBER: builtins.int
    IDLE_START_TIME_FIELD_NUMBER: builtins.int
    auto_delete_time: builtins.str
    idle_delete_ttl: builtins.str
    idle_start_time: builtins.str
    def __init__(
        self,
        *,
        auto_delete_time: builtins.str = ...,
        idle_delete_ttl: builtins.str = ...,
        idle_start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_time", b"auto_delete_time", "idle_delete_ttl", b"idle_delete_ttl", "idle_start_time", b"idle_start_time"]) -> None: ...

global___DataprocClusterXClusterConfigXLifecycleConfig = DataprocClusterXClusterConfigXLifecycleConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXMasterConfigXAccelerators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_COUNT_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    accelerator_count: builtins.float
    accelerator_type: builtins.str
    def __init__(
        self,
        *,
        accelerator_count: builtins.float = ...,
        accelerator_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_count", b"accelerator_count", "accelerator_type", b"accelerator_type"]) -> None: ...

global___DataprocClusterXClusterConfigXMasterConfigXAccelerators = DataprocClusterXClusterConfigXMasterConfigXAccelerators

@typing_extensions.final
class DataprocClusterXClusterConfigXMasterConfigXDiskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    NUM_LOCAL_SSDS_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    num_local_ssds: builtins.float
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        num_local_ssds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "num_local_ssds", b"num_local_ssds"]) -> None: ...

global___DataprocClusterXClusterConfigXMasterConfigXDiskConfig = DataprocClusterXClusterConfigXMasterConfigXDiskConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXMasterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URI_FIELD_NUMBER: builtins.int
    INSTANCE_NAMES_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NUM_INSTANCES_FIELD_NUMBER: builtins.int
    ACCELERATORS_FIELD_NUMBER: builtins.int
    DISK_CONFIG_FIELD_NUMBER: builtins.int
    image_uri: builtins.str
    @property
    def instance_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    machine_type: builtins.str
    min_cpu_platform: builtins.str
    num_instances: builtins.float
    @property
    def accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocClusterXClusterConfigXMasterConfigXAccelerators]: ...
    @property
    def disk_config(self) -> global___DataprocClusterXClusterConfigXMasterConfigXDiskConfig: ...
    def __init__(
        self,
        *,
        image_uri: builtins.str = ...,
        instance_names: collections.abc.Iterable[builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        num_instances: builtins.float = ...,
        accelerators: collections.abc.Iterable[global___DataprocClusterXClusterConfigXMasterConfigXAccelerators] | None = ...,
        disk_config: global___DataprocClusterXClusterConfigXMasterConfigXDiskConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_config", b"disk_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerators", b"accelerators", "disk_config", b"disk_config", "image_uri", b"image_uri", "instance_names", b"instance_names", "machine_type", b"machine_type", "min_cpu_platform", b"min_cpu_platform", "num_instances", b"num_instances"]) -> None: ...

global___DataprocClusterXClusterConfigXMasterConfig = DataprocClusterXClusterConfigXMasterConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXMetastoreConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAPROC_METASTORE_SERVICE_FIELD_NUMBER: builtins.int
    dataproc_metastore_service: builtins.str
    def __init__(
        self,
        *,
        dataproc_metastore_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataproc_metastore_service", b"dataproc_metastore_service"]) -> None: ...

global___DataprocClusterXClusterConfigXMetastoreConfig = DataprocClusterXClusterConfigXMetastoreConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXPreemptibleWorkerConfigXDiskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    NUM_LOCAL_SSDS_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    num_local_ssds: builtins.float
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        num_local_ssds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "num_local_ssds", b"num_local_ssds"]) -> None: ...

global___DataprocClusterXClusterConfigXPreemptibleWorkerConfigXDiskConfig = DataprocClusterXClusterConfigXPreemptibleWorkerConfigXDiskConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXPreemptibleWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_NAMES_FIELD_NUMBER: builtins.int
    NUM_INSTANCES_FIELD_NUMBER: builtins.int
    PREEMPTIBILITY_FIELD_NUMBER: builtins.int
    DISK_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def instance_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    num_instances: builtins.float
    preemptibility: builtins.str
    @property
    def disk_config(self) -> global___DataprocClusterXClusterConfigXPreemptibleWorkerConfigXDiskConfig: ...
    def __init__(
        self,
        *,
        instance_names: collections.abc.Iterable[builtins.str] | None = ...,
        num_instances: builtins.float = ...,
        preemptibility: builtins.str = ...,
        disk_config: global___DataprocClusterXClusterConfigXPreemptibleWorkerConfigXDiskConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_config", b"disk_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_config", b"disk_config", "instance_names", b"instance_names", "num_instances", b"num_instances", "preemptibility", b"preemptibility"]) -> None: ...

global___DataprocClusterXClusterConfigXPreemptibleWorkerConfig = DataprocClusterXClusterConfigXPreemptibleWorkerConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXSecurityConfigXKerberosConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CROSS_REALM_TRUST_ADMIN_SERVER_FIELD_NUMBER: builtins.int
    CROSS_REALM_TRUST_KDC_FIELD_NUMBER: builtins.int
    CROSS_REALM_TRUST_REALM_FIELD_NUMBER: builtins.int
    CROSS_REALM_TRUST_SHARED_PASSWORD_URI_FIELD_NUMBER: builtins.int
    ENABLE_KERBEROS_FIELD_NUMBER: builtins.int
    KDC_DB_KEY_URI_FIELD_NUMBER: builtins.int
    KEY_PASSWORD_URI_FIELD_NUMBER: builtins.int
    KEYSTORE_PASSWORD_URI_FIELD_NUMBER: builtins.int
    KEYSTORE_URI_FIELD_NUMBER: builtins.int
    KMS_KEY_URI_FIELD_NUMBER: builtins.int
    REALM_FIELD_NUMBER: builtins.int
    ROOT_PRINCIPAL_PASSWORD_URI_FIELD_NUMBER: builtins.int
    TGT_LIFETIME_HOURS_FIELD_NUMBER: builtins.int
    TRUSTSTORE_PASSWORD_URI_FIELD_NUMBER: builtins.int
    TRUSTSTORE_URI_FIELD_NUMBER: builtins.int
    cross_realm_trust_admin_server: builtins.str
    cross_realm_trust_kdc: builtins.str
    cross_realm_trust_realm: builtins.str
    cross_realm_trust_shared_password_uri: builtins.str
    enable_kerberos: builtins.bool
    kdc_db_key_uri: builtins.str
    key_password_uri: builtins.str
    keystore_password_uri: builtins.str
    keystore_uri: builtins.str
    kms_key_uri: builtins.str
    realm: builtins.str
    root_principal_password_uri: builtins.str
    tgt_lifetime_hours: builtins.float
    truststore_password_uri: builtins.str
    truststore_uri: builtins.str
    def __init__(
        self,
        *,
        cross_realm_trust_admin_server: builtins.str = ...,
        cross_realm_trust_kdc: builtins.str = ...,
        cross_realm_trust_realm: builtins.str = ...,
        cross_realm_trust_shared_password_uri: builtins.str = ...,
        enable_kerberos: builtins.bool = ...,
        kdc_db_key_uri: builtins.str = ...,
        key_password_uri: builtins.str = ...,
        keystore_password_uri: builtins.str = ...,
        keystore_uri: builtins.str = ...,
        kms_key_uri: builtins.str = ...,
        realm: builtins.str = ...,
        root_principal_password_uri: builtins.str = ...,
        tgt_lifetime_hours: builtins.float = ...,
        truststore_password_uri: builtins.str = ...,
        truststore_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cross_realm_trust_admin_server", b"cross_realm_trust_admin_server", "cross_realm_trust_kdc", b"cross_realm_trust_kdc", "cross_realm_trust_realm", b"cross_realm_trust_realm", "cross_realm_trust_shared_password_uri", b"cross_realm_trust_shared_password_uri", "enable_kerberos", b"enable_kerberos", "kdc_db_key_uri", b"kdc_db_key_uri", "key_password_uri", b"key_password_uri", "keystore_password_uri", b"keystore_password_uri", "keystore_uri", b"keystore_uri", "kms_key_uri", b"kms_key_uri", "realm", b"realm", "root_principal_password_uri", b"root_principal_password_uri", "tgt_lifetime_hours", b"tgt_lifetime_hours", "truststore_password_uri", b"truststore_password_uri", "truststore_uri", b"truststore_uri"]) -> None: ...

global___DataprocClusterXClusterConfigXSecurityConfigXKerberosConfig = DataprocClusterXClusterConfigXSecurityConfigXKerberosConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXSecurityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KERBEROS_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def kerberos_config(self) -> global___DataprocClusterXClusterConfigXSecurityConfigXKerberosConfig: ...
    def __init__(
        self,
        *,
        kerberos_config: global___DataprocClusterXClusterConfigXSecurityConfigXKerberosConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kerberos_config", b"kerberos_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kerberos_config", b"kerberos_config"]) -> None: ...

global___DataprocClusterXClusterConfigXSecurityConfig = DataprocClusterXClusterConfigXSecurityConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXSoftwareConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OverridePropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_VERSION_FIELD_NUMBER: builtins.int
    OPTIONAL_COMPONENTS_FIELD_NUMBER: builtins.int
    OVERRIDE_PROPERTIES_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    image_version: builtins.str
    @property
    def optional_components(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def override_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        image_version: builtins.str = ...,
        optional_components: collections.abc.Iterable[builtins.str] | None = ...,
        override_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_version", b"image_version", "optional_components", b"optional_components", "override_properties", b"override_properties", "properties", b"properties"]) -> None: ...

global___DataprocClusterXClusterConfigXSoftwareConfig = DataprocClusterXClusterConfigXSoftwareConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXWorkerConfigXAccelerators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_COUNT_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    accelerator_count: builtins.float
    accelerator_type: builtins.str
    def __init__(
        self,
        *,
        accelerator_count: builtins.float = ...,
        accelerator_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_count", b"accelerator_count", "accelerator_type", b"accelerator_type"]) -> None: ...

global___DataprocClusterXClusterConfigXWorkerConfigXAccelerators = DataprocClusterXClusterConfigXWorkerConfigXAccelerators

@typing_extensions.final
class DataprocClusterXClusterConfigXWorkerConfigXDiskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    NUM_LOCAL_SSDS_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    num_local_ssds: builtins.float
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        num_local_ssds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "num_local_ssds", b"num_local_ssds"]) -> None: ...

global___DataprocClusterXClusterConfigXWorkerConfigXDiskConfig = DataprocClusterXClusterConfigXWorkerConfigXDiskConfig

@typing_extensions.final
class DataprocClusterXClusterConfigXWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URI_FIELD_NUMBER: builtins.int
    INSTANCE_NAMES_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NUM_INSTANCES_FIELD_NUMBER: builtins.int
    ACCELERATORS_FIELD_NUMBER: builtins.int
    DISK_CONFIG_FIELD_NUMBER: builtins.int
    image_uri: builtins.str
    @property
    def instance_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    machine_type: builtins.str
    min_cpu_platform: builtins.str
    num_instances: builtins.float
    @property
    def accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocClusterXClusterConfigXWorkerConfigXAccelerators]: ...
    @property
    def disk_config(self) -> global___DataprocClusterXClusterConfigXWorkerConfigXDiskConfig: ...
    def __init__(
        self,
        *,
        image_uri: builtins.str = ...,
        instance_names: collections.abc.Iterable[builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        num_instances: builtins.float = ...,
        accelerators: collections.abc.Iterable[global___DataprocClusterXClusterConfigXWorkerConfigXAccelerators] | None = ...,
        disk_config: global___DataprocClusterXClusterConfigXWorkerConfigXDiskConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_config", b"disk_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerators", b"accelerators", "disk_config", b"disk_config", "image_uri", b"image_uri", "instance_names", b"instance_names", "machine_type", b"machine_type", "min_cpu_platform", b"min_cpu_platform", "num_instances", b"num_instances"]) -> None: ...

global___DataprocClusterXClusterConfigXWorkerConfig = DataprocClusterXClusterConfigXWorkerConfig

@typing_extensions.final
class DataprocClusterXClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    STAGING_BUCKET_FIELD_NUMBER: builtins.int
    TEMP_BUCKET_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_FIELD_NUMBER: builtins.int
    GCE_CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    INITIALIZATION_ACTION_FIELD_NUMBER: builtins.int
    LIFECYCLE_CONFIG_FIELD_NUMBER: builtins.int
    MASTER_CONFIG_FIELD_NUMBER: builtins.int
    METASTORE_CONFIG_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_WORKER_CONFIG_FIELD_NUMBER: builtins.int
    SECURITY_CONFIG_FIELD_NUMBER: builtins.int
    SOFTWARE_CONFIG_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    staging_bucket: builtins.str
    temp_bucket: builtins.str
    @property
    def autoscaling_config(self) -> global___DataprocClusterXClusterConfigXAutoscalingConfig: ...
    @property
    def encryption_config(self) -> global___DataprocClusterXClusterConfigXEncryptionConfig: ...
    @property
    def endpoint_config(self) -> global___DataprocClusterXClusterConfigXEndpointConfig: ...
    @property
    def gce_cluster_config(self) -> global___DataprocClusterXClusterConfigXGceClusterConfig: ...
    @property
    def initialization_action(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocClusterXClusterConfigXInitializationAction]: ...
    @property
    def lifecycle_config(self) -> global___DataprocClusterXClusterConfigXLifecycleConfig: ...
    @property
    def master_config(self) -> global___DataprocClusterXClusterConfigXMasterConfig: ...
    @property
    def metastore_config(self) -> global___DataprocClusterXClusterConfigXMetastoreConfig: ...
    @property
    def preemptible_worker_config(self) -> global___DataprocClusterXClusterConfigXPreemptibleWorkerConfig: ...
    @property
    def security_config(self) -> global___DataprocClusterXClusterConfigXSecurityConfig: ...
    @property
    def software_config(self) -> global___DataprocClusterXClusterConfigXSoftwareConfig: ...
    @property
    def worker_config(self) -> global___DataprocClusterXClusterConfigXWorkerConfig: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        staging_bucket: builtins.str = ...,
        temp_bucket: builtins.str = ...,
        autoscaling_config: global___DataprocClusterXClusterConfigXAutoscalingConfig | None = ...,
        encryption_config: global___DataprocClusterXClusterConfigXEncryptionConfig | None = ...,
        endpoint_config: global___DataprocClusterXClusterConfigXEndpointConfig | None = ...,
        gce_cluster_config: global___DataprocClusterXClusterConfigXGceClusterConfig | None = ...,
        initialization_action: collections.abc.Iterable[global___DataprocClusterXClusterConfigXInitializationAction] | None = ...,
        lifecycle_config: global___DataprocClusterXClusterConfigXLifecycleConfig | None = ...,
        master_config: global___DataprocClusterXClusterConfigXMasterConfig | None = ...,
        metastore_config: global___DataprocClusterXClusterConfigXMetastoreConfig | None = ...,
        preemptible_worker_config: global___DataprocClusterXClusterConfigXPreemptibleWorkerConfig | None = ...,
        security_config: global___DataprocClusterXClusterConfigXSecurityConfig | None = ...,
        software_config: global___DataprocClusterXClusterConfigXSoftwareConfig | None = ...,
        worker_config: global___DataprocClusterXClusterConfigXWorkerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config", "encryption_config", b"encryption_config", "endpoint_config", b"endpoint_config", "gce_cluster_config", b"gce_cluster_config", "lifecycle_config", b"lifecycle_config", "master_config", b"master_config", "metastore_config", b"metastore_config", "preemptible_worker_config", b"preemptible_worker_config", "security_config", b"security_config", "software_config", b"software_config", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config", "bucket", b"bucket", "encryption_config", b"encryption_config", "endpoint_config", b"endpoint_config", "gce_cluster_config", b"gce_cluster_config", "initialization_action", b"initialization_action", "lifecycle_config", b"lifecycle_config", "master_config", b"master_config", "metastore_config", b"metastore_config", "preemptible_worker_config", b"preemptible_worker_config", "security_config", b"security_config", "software_config", b"software_config", "staging_bucket", b"staging_bucket", "temp_bucket", b"temp_bucket", "worker_config", b"worker_config"]) -> None: ...

global___DataprocClusterXClusterConfig = DataprocClusterXClusterConfig

@typing_extensions.final
class DataprocClusterXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataprocClusterXTimeouts = DataprocClusterXTimeouts

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXMetastoreConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAPROC_METASTORE_SERVICE_FIELD_NUMBER: builtins.int
    dataproc_metastore_service: builtins.str
    def __init__(
        self,
        *,
        dataproc_metastore_service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataproc_metastore_service", b"dataproc_metastore_service"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXMetastoreConfig = DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXMetastoreConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXSparkHistoryServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAPROC_CLUSTER_FIELD_NUMBER: builtins.int
    dataproc_cluster: builtins.str
    def __init__(
        self,
        *,
        dataproc_cluster: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataproc_cluster", b"dataproc_cluster"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXSparkHistoryServerConfig = DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXSparkHistoryServerConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METASTORE_CONFIG_FIELD_NUMBER: builtins.int
    SPARK_HISTORY_SERVER_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def metastore_config(self) -> global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXMetastoreConfig: ...
    @property
    def spark_history_server_config(self) -> global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXSparkHistoryServerConfig: ...
    def __init__(
        self,
        *,
        metastore_config: global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXMetastoreConfig | None = ...,
        spark_history_server_config: global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfigXSparkHistoryServerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metastore_config", b"metastore_config", "spark_history_server_config", b"spark_history_server_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metastore_config", b"metastore_config", "spark_history_server_config", b"spark_history_server_config"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfig = DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXAutoscaling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_NODE_COUNT_FIELD_NUMBER: builtins.int
    MIN_NODE_COUNT_FIELD_NUMBER: builtins.int
    max_node_count: builtins.float
    min_node_count: builtins.float
    def __init__(
        self,
        *,
        max_node_count: builtins.float = ...,
        min_node_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_node_count", b"max_node_count", "min_node_count", b"min_node_count"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXAutoscaling = DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXAutoscaling

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCAL_SSD_COUNT_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    SPOT_FIELD_NUMBER: builtins.int
    local_ssd_count: builtins.float
    machine_type: builtins.str
    min_cpu_platform: builtins.str
    preemptible: builtins.bool
    spot: builtins.bool
    def __init__(
        self,
        *,
        local_ssd_count: builtins.float = ...,
        machine_type: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        preemptible: builtins.bool = ...,
        spot: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["local_ssd_count", b"local_ssd_count", "machine_type", b"machine_type", "min_cpu_platform", b"min_cpu_platform", "preemptible", b"preemptible", "spot", b"spot"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXConfig = DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATIONS_FIELD_NUMBER: builtins.int
    AUTOSCALING_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def autoscaling(self) -> global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXAutoscaling: ...
    @property
    def config(self) -> global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXConfig: ...
    def __init__(
        self,
        *,
        locations: collections.abc.Iterable[builtins.str] | None = ...,
        autoscaling: global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXAutoscaling | None = ...,
        config: global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfigXConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling", b"autoscaling", "config", b"config", "locations", b"locations"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfig = DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_POOL_FIELD_NUMBER: builtins.int
    ROLES_FIELD_NUMBER: builtins.int
    NODE_POOL_CONFIG_FIELD_NUMBER: builtins.int
    node_pool: builtins.str
    @property
    def roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def node_pool_config(self) -> global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfig: ...
    def __init__(
        self,
        *,
        node_pool: builtins.str = ...,
        roles: collections.abc.Iterable[builtins.str] | None = ...,
        node_pool_config: global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTargetXNodePoolConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["node_pool_config", b"node_pool_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["node_pool", b"node_pool", "node_pool_config", b"node_pool_config", "roles", b"roles"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTarget = DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTarget

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GKE_CLUSTER_TARGET_FIELD_NUMBER: builtins.int
    NODE_POOL_TARGET_FIELD_NUMBER: builtins.int
    gke_cluster_target: builtins.str
    @property
    def node_pool_target(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTarget]: ...
    def __init__(
        self,
        *,
        gke_cluster_target: builtins.str = ...,
        node_pool_target: collections.abc.Iterable[global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfigXNodePoolTarget] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gke_cluster_target", b"gke_cluster_target", "node_pool_target", b"node_pool_target"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfig = DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ComponentVersionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMPONENT_VERSION_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    @property
    def component_version(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        component_version: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_version", b"component_version", "properties", b"properties"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig = DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfigXKubernetesClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KUBERNETES_NAMESPACE_FIELD_NUMBER: builtins.int
    GKE_CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_SOFTWARE_CONFIG_FIELD_NUMBER: builtins.int
    kubernetes_namespace: builtins.str
    @property
    def gke_cluster_config(self) -> global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfig: ...
    @property
    def kubernetes_software_config(self) -> global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig: ...
    def __init__(
        self,
        *,
        kubernetes_namespace: builtins.str = ...,
        gke_cluster_config: global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXGkeClusterConfig | None = ...,
        kubernetes_software_config: global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfigXKubernetesSoftwareConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gke_cluster_config", b"gke_cluster_config", "kubernetes_software_config", b"kubernetes_software_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["gke_cluster_config", b"gke_cluster_config", "kubernetes_namespace", b"kubernetes_namespace", "kubernetes_software_config", b"kubernetes_software_config"]) -> None: ...

global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfig = DataprocClusterXVirtualClusterConfigXKubernetesClusterConfig

@typing_extensions.final
class DataprocClusterXVirtualClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STAGING_BUCKET_FIELD_NUMBER: builtins.int
    AUXILIARY_SERVICES_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    staging_bucket: builtins.str
    @property
    def auxiliary_services_config(self) -> global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfig: ...
    @property
    def kubernetes_cluster_config(self) -> global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfig: ...
    def __init__(
        self,
        *,
        staging_bucket: builtins.str = ...,
        auxiliary_services_config: global___DataprocClusterXVirtualClusterConfigXAuxiliaryServicesConfig | None = ...,
        kubernetes_cluster_config: global___DataprocClusterXVirtualClusterConfigXKubernetesClusterConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auxiliary_services_config", b"auxiliary_services_config", "kubernetes_cluster_config", b"kubernetes_cluster_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auxiliary_services_config", b"auxiliary_services_config", "kubernetes_cluster_config", b"kubernetes_cluster_config", "staging_bucket", b"staging_bucket"]) -> None: ...

global___DataprocClusterXVirtualClusterConfig = DataprocClusterXVirtualClusterConfig

@typing_extensions.final
class DataprocCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    GRACEFUL_DECOMMISSION_TIMEOUT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VIRTUAL_CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    graceful_decommission_timeout: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def cluster_config(self) -> global___DataprocClusterXClusterConfig: ...
    @property
    def timeouts(self) -> global___DataprocClusterXTimeouts: ...
    @property
    def virtual_cluster_config(self) -> global___DataprocClusterXVirtualClusterConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        graceful_decommission_timeout: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        cluster_config: global___DataprocClusterXClusterConfig | None = ...,
        timeouts: global___DataprocClusterXTimeouts | None = ...,
        virtual_cluster_config: global___DataprocClusterXVirtualClusterConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_config", b"cluster_config", "resource_info", b"resource_info", "timeouts", b"timeouts", "virtual_cluster_config", b"virtual_cluster_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_config", b"cluster_config", "graceful_decommission_timeout", b"graceful_decommission_timeout", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts", "virtual_cluster_config", b"virtual_cluster_config"]) -> None: ...

global___DataprocCluster = DataprocCluster

@typing_extensions.final
class DataprocClusterIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocClusterIamBindingXCondition = DataprocClusterIamBindingXCondition

@typing_extensions.final
class DataprocClusterIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataprocClusterIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataprocClusterIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataprocClusterIamBinding = DataprocClusterIamBinding

@typing_extensions.final
class DataprocClusterIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocClusterIamMemberXCondition = DataprocClusterIamMemberXCondition

@typing_extensions.final
class DataprocClusterIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataprocClusterIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataprocClusterIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataprocClusterIamMember = DataprocClusterIamMember

@typing_extensions.final
class DataprocClusterIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___DataprocClusterIamPolicy = DataprocClusterIamPolicy

@typing_extensions.final
class DataprocJobXHadoopConfigXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocJobXHadoopConfigXLoggingConfig = DataprocJobXHadoopConfigXLoggingConfig

@typing_extensions.final
class DataprocJobXHadoopConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    MAIN_JAR_FILE_URI_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    main_class: builtins.str
    main_jar_file_uri: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocJobXHadoopConfigXLoggingConfig: ...
    def __init__(
        self,
        *,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        main_class: builtins.str = ...,
        main_jar_file_uri: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocJobXHadoopConfigXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_uris", b"archive_uris", "args", b"args", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "main_class", b"main_class", "main_jar_file_uri", b"main_jar_file_uri", "properties", b"properties"]) -> None: ...

global___DataprocJobXHadoopConfig = DataprocJobXHadoopConfig

@typing_extensions.final
class DataprocJobXHiveConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ScriptVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTINUE_ON_FAILURE_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    SCRIPT_VARIABLES_FIELD_NUMBER: builtins.int
    continue_on_failure: builtins.bool
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def query_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def script_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        continue_on_failure: builtins.bool = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        query_list: collections.abc.Iterable[builtins.str] | None = ...,
        script_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue_on_failure", b"continue_on_failure", "jar_file_uris", b"jar_file_uris", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list", "script_variables", b"script_variables"]) -> None: ...

global___DataprocJobXHiveConfig = DataprocJobXHiveConfig

@typing_extensions.final
class DataprocJobXPigConfigXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocJobXPigConfigXLoggingConfig = DataprocJobXPigConfigXLoggingConfig

@typing_extensions.final
class DataprocJobXPigConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ScriptVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTINUE_ON_FAILURE_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    SCRIPT_VARIABLES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    continue_on_failure: builtins.bool
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def query_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def script_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocJobXPigConfigXLoggingConfig: ...
    def __init__(
        self,
        *,
        continue_on_failure: builtins.bool = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        query_list: collections.abc.Iterable[builtins.str] | None = ...,
        script_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocJobXPigConfigXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue_on_failure", b"continue_on_failure", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list", "script_variables", b"script_variables"]) -> None: ...

global___DataprocJobXPigConfig = DataprocJobXPigConfig

@typing_extensions.final
class DataprocJobXPlacement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    CLUSTER_UUID_FIELD_NUMBER: builtins.int
    cluster_name: builtins.str
    cluster_uuid: builtins.str
    def __init__(
        self,
        *,
        cluster_name: builtins.str = ...,
        cluster_uuid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_name", b"cluster_name", "cluster_uuid", b"cluster_uuid"]) -> None: ...

global___DataprocJobXPlacement = DataprocJobXPlacement

@typing_extensions.final
class DataprocJobXPrestoConfigXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocJobXPrestoConfigXLoggingConfig = DataprocJobXPrestoConfigXLoggingConfig

@typing_extensions.final
class DataprocJobXPrestoConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLIENT_TAGS_FIELD_NUMBER: builtins.int
    CONTINUE_ON_FAILURE_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def client_tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    continue_on_failure: builtins.bool
    output_format: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def query_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocJobXPrestoConfigXLoggingConfig: ...
    def __init__(
        self,
        *,
        client_tags: collections.abc.Iterable[builtins.str] | None = ...,
        continue_on_failure: builtins.bool = ...,
        output_format: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        query_list: collections.abc.Iterable[builtins.str] | None = ...,
        logging_config: global___DataprocJobXPrestoConfigXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_tags", b"client_tags", "continue_on_failure", b"continue_on_failure", "logging_config", b"logging_config", "output_format", b"output_format", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list"]) -> None: ...

global___DataprocJobXPrestoConfig = DataprocJobXPrestoConfig

@typing_extensions.final
class DataprocJobXPysparkConfigXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocJobXPysparkConfigXLoggingConfig = DataprocJobXPysparkConfigXLoggingConfig

@typing_extensions.final
class DataprocJobXPysparkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    MAIN_PYTHON_FILE_URI_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    PYTHON_FILE_URIS_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    main_python_file_uri: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def python_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocJobXPysparkConfigXLoggingConfig: ...
    def __init__(
        self,
        *,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        main_python_file_uri: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        python_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        logging_config: global___DataprocJobXPysparkConfigXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_uris", b"archive_uris", "args", b"args", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "main_python_file_uri", b"main_python_file_uri", "properties", b"properties", "python_file_uris", b"python_file_uris"]) -> None: ...

global___DataprocJobXPysparkConfig = DataprocJobXPysparkConfig

@typing_extensions.final
class DataprocJobXReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id"]) -> None: ...

global___DataprocJobXReference = DataprocJobXReference

@typing_extensions.final
class DataprocJobXScheduling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_FAILURES_PER_HOUR_FIELD_NUMBER: builtins.int
    MAX_FAILURES_TOTAL_FIELD_NUMBER: builtins.int
    max_failures_per_hour: builtins.float
    max_failures_total: builtins.float
    def __init__(
        self,
        *,
        max_failures_per_hour: builtins.float = ...,
        max_failures_total: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_failures_per_hour", b"max_failures_per_hour", "max_failures_total", b"max_failures_total"]) -> None: ...

global___DataprocJobXScheduling = DataprocJobXScheduling

@typing_extensions.final
class DataprocJobXSparkConfigXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocJobXSparkConfigXLoggingConfig = DataprocJobXSparkConfigXLoggingConfig

@typing_extensions.final
class DataprocJobXSparkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    MAIN_JAR_FILE_URI_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    main_class: builtins.str
    main_jar_file_uri: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocJobXSparkConfigXLoggingConfig: ...
    def __init__(
        self,
        *,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        main_class: builtins.str = ...,
        main_jar_file_uri: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocJobXSparkConfigXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_uris", b"archive_uris", "args", b"args", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "main_class", b"main_class", "main_jar_file_uri", b"main_jar_file_uri", "properties", b"properties"]) -> None: ...

global___DataprocJobXSparkConfig = DataprocJobXSparkConfig

@typing_extensions.final
class DataprocJobXSparksqlConfigXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocJobXSparksqlConfigXLoggingConfig = DataprocJobXSparksqlConfigXLoggingConfig

@typing_extensions.final
class DataprocJobXSparksqlConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ScriptVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    SCRIPT_VARIABLES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def query_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def script_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocJobXSparksqlConfigXLoggingConfig: ...
    def __init__(
        self,
        *,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        query_list: collections.abc.Iterable[builtins.str] | None = ...,
        script_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocJobXSparksqlConfigXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list", "script_variables", b"script_variables"]) -> None: ...

global___DataprocJobXSparksqlConfig = DataprocJobXSparksqlConfig

@typing_extensions.final
class DataprocJobXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___DataprocJobXTimeouts = DataprocJobXTimeouts

@typing_extensions.final
class DataprocJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class StatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_CONTROLS_FILES_URI_FIELD_NUMBER: builtins.int
    DRIVER_OUTPUT_RESOURCE_URI_FIELD_NUMBER: builtins.int
    FORCE_DELETE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    HADOOP_CONFIG_FIELD_NUMBER: builtins.int
    HIVE_CONFIG_FIELD_NUMBER: builtins.int
    PIG_CONFIG_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    PRESTO_CONFIG_FIELD_NUMBER: builtins.int
    PYSPARK_CONFIG_FIELD_NUMBER: builtins.int
    REFERENCE_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    SPARK_CONFIG_FIELD_NUMBER: builtins.int
    SPARKSQL_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    driver_controls_files_uri: builtins.str
    driver_output_resource_uri: builtins.str
    force_delete: builtins.bool
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    project: builtins.str
    region: builtins.str
    @property
    def status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def hadoop_config(self) -> global___DataprocJobXHadoopConfig: ...
    @property
    def hive_config(self) -> global___DataprocJobXHiveConfig: ...
    @property
    def pig_config(self) -> global___DataprocJobXPigConfig: ...
    @property
    def placement(self) -> global___DataprocJobXPlacement: ...
    @property
    def presto_config(self) -> global___DataprocJobXPrestoConfig: ...
    @property
    def pyspark_config(self) -> global___DataprocJobXPysparkConfig: ...
    @property
    def reference(self) -> global___DataprocJobXReference: ...
    @property
    def scheduling(self) -> global___DataprocJobXScheduling: ...
    @property
    def spark_config(self) -> global___DataprocJobXSparkConfig: ...
    @property
    def sparksql_config(self) -> global___DataprocJobXSparksqlConfig: ...
    @property
    def timeouts(self) -> global___DataprocJobXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        driver_controls_files_uri: builtins.str = ...,
        driver_output_resource_uri: builtins.str = ...,
        force_delete: builtins.bool = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        hadoop_config: global___DataprocJobXHadoopConfig | None = ...,
        hive_config: global___DataprocJobXHiveConfig | None = ...,
        pig_config: global___DataprocJobXPigConfig | None = ...,
        placement: global___DataprocJobXPlacement | None = ...,
        presto_config: global___DataprocJobXPrestoConfig | None = ...,
        pyspark_config: global___DataprocJobXPysparkConfig | None = ...,
        reference: global___DataprocJobXReference | None = ...,
        scheduling: global___DataprocJobXScheduling | None = ...,
        spark_config: global___DataprocJobXSparkConfig | None = ...,
        sparksql_config: global___DataprocJobXSparksqlConfig | None = ...,
        timeouts: global___DataprocJobXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hadoop_config", b"hadoop_config", "hive_config", b"hive_config", "pig_config", b"pig_config", "placement", b"placement", "presto_config", b"presto_config", "pyspark_config", b"pyspark_config", "reference", b"reference", "resource_info", b"resource_info", "scheduling", b"scheduling", "spark_config", b"spark_config", "sparksql_config", b"sparksql_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_controls_files_uri", b"driver_controls_files_uri", "driver_output_resource_uri", b"driver_output_resource_uri", "force_delete", b"force_delete", "hadoop_config", b"hadoop_config", "hive_config", b"hive_config", "id", b"id", "labels", b"labels", "pig_config", b"pig_config", "placement", b"placement", "presto_config", b"presto_config", "project", b"project", "pyspark_config", b"pyspark_config", "reference", b"reference", "region", b"region", "resource_info", b"resource_info", "scheduling", b"scheduling", "spark_config", b"spark_config", "sparksql_config", b"sparksql_config", "status", b"status", "timeouts", b"timeouts"]) -> None: ...

global___DataprocJob = DataprocJob

@typing_extensions.final
class DataprocJobIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocJobIamBindingXCondition = DataprocJobIamBindingXCondition

@typing_extensions.final
class DataprocJobIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    job_id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataprocJobIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        job_id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataprocJobIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "job_id", b"job_id", "members", b"members", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataprocJobIamBinding = DataprocJobIamBinding

@typing_extensions.final
class DataprocJobIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocJobIamMemberXCondition = DataprocJobIamMemberXCondition

@typing_extensions.final
class DataprocJobIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    job_id: builtins.str
    member: builtins.str
    project: builtins.str
    region: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___DataprocJobIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        job_id: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___DataprocJobIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "job_id", b"job_id", "member", b"member", "project", b"project", "region", b"region", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___DataprocJobIamMember = DataprocJobIamMember

@typing_extensions.final
class DataprocJobIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    job_id: builtins.str
    policy_data: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        job_id: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "job_id", b"job_id", "policy_data", b"policy_data", "project", b"project", "region", b"region", "resource_info", b"resource_info"]) -> None: ...

global___DataprocJobIamPolicy = DataprocJobIamPolicy

@typing_extensions.final
class DataprocMetastoreServiceXEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_FIELD_NUMBER: builtins.int
    kms_key: builtins.str
    def __init__(
        self,
        *,
        kms_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key", b"kms_key"]) -> None: ...

global___DataprocMetastoreServiceXEncryptionConfig = DataprocMetastoreServiceXEncryptionConfig

@typing_extensions.final
class DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfigXKeytab(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_SECRET_FIELD_NUMBER: builtins.int
    cloud_secret: builtins.str
    def __init__(
        self,
        *,
        cloud_secret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_secret", b"cloud_secret"]) -> None: ...

global___DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfigXKeytab = DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfigXKeytab

@typing_extensions.final
class DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KRB5_CONFIG_GCS_URI_FIELD_NUMBER: builtins.int
    PRINCIPAL_FIELD_NUMBER: builtins.int
    KEYTAB_FIELD_NUMBER: builtins.int
    krb5_config_gcs_uri: builtins.str
    principal: builtins.str
    @property
    def keytab(self) -> global___DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfigXKeytab: ...
    def __init__(
        self,
        *,
        krb5_config_gcs_uri: builtins.str = ...,
        principal: builtins.str = ...,
        keytab: global___DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfigXKeytab | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["keytab", b"keytab"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["keytab", b"keytab", "krb5_config_gcs_uri", b"krb5_config_gcs_uri", "principal", b"principal"]) -> None: ...

global___DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfig = DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfig

@typing_extensions.final
class DataprocMetastoreServiceXHiveMetastoreConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ConfigOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIG_OVERRIDES_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    KERBEROS_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    version: builtins.str
    @property
    def kerberos_config(self) -> global___DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfig: ...
    def __init__(
        self,
        *,
        config_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        version: builtins.str = ...,
        kerberos_config: global___DataprocMetastoreServiceXHiveMetastoreConfigXKerberosConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kerberos_config", b"kerberos_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config_overrides", b"config_overrides", "kerberos_config", b"kerberos_config", "version", b"version"]) -> None: ...

global___DataprocMetastoreServiceXHiveMetastoreConfig = DataprocMetastoreServiceXHiveMetastoreConfig

@typing_extensions.final
class DataprocMetastoreServiceXMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_OF_WEEK_FIELD_NUMBER: builtins.int
    HOUR_OF_DAY_FIELD_NUMBER: builtins.int
    day_of_week: builtins.str
    hour_of_day: builtins.float
    def __init__(
        self,
        *,
        day_of_week: builtins.str = ...,
        hour_of_day: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day_of_week", b"day_of_week", "hour_of_day", b"hour_of_day"]) -> None: ...

global___DataprocMetastoreServiceXMaintenanceWindow = DataprocMetastoreServiceXMaintenanceWindow

@typing_extensions.final
class DataprocMetastoreServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___DataprocMetastoreServiceXTimeouts = DataprocMetastoreServiceXTimeouts

@typing_extensions.final
class DataprocMetastoreService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARTIFACT_GCS_URI_FIELD_NUMBER: builtins.int
    DATABASE_TYPE_FIELD_NUMBER: builtins.int
    ENDPOINT_URI_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STATE_MESSAGE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    HIVE_METASTORE_CONFIG_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    artifact_gcs_uri: builtins.str
    database_type: builtins.str
    endpoint_uri: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    network: builtins.str
    port: builtins.float
    project: builtins.str
    release_channel: builtins.str
    service_id: builtins.str
    state: builtins.str
    state_message: builtins.str
    tier: builtins.str
    uid: builtins.str
    @property
    def encryption_config(self) -> global___DataprocMetastoreServiceXEncryptionConfig: ...
    @property
    def hive_metastore_config(self) -> global___DataprocMetastoreServiceXHiveMetastoreConfig: ...
    @property
    def maintenance_window(self) -> global___DataprocMetastoreServiceXMaintenanceWindow: ...
    @property
    def timeouts(self) -> global___DataprocMetastoreServiceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        artifact_gcs_uri: builtins.str = ...,
        database_type: builtins.str = ...,
        endpoint_uri: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        release_channel: builtins.str = ...,
        service_id: builtins.str = ...,
        state: builtins.str = ...,
        state_message: builtins.str = ...,
        tier: builtins.str = ...,
        uid: builtins.str = ...,
        encryption_config: global___DataprocMetastoreServiceXEncryptionConfig | None = ...,
        hive_metastore_config: global___DataprocMetastoreServiceXHiveMetastoreConfig | None = ...,
        maintenance_window: global___DataprocMetastoreServiceXMaintenanceWindow | None = ...,
        timeouts: global___DataprocMetastoreServiceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption_config", b"encryption_config", "hive_metastore_config", b"hive_metastore_config", "maintenance_window", b"maintenance_window", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifact_gcs_uri", b"artifact_gcs_uri", "database_type", b"database_type", "encryption_config", b"encryption_config", "endpoint_uri", b"endpoint_uri", "hive_metastore_config", b"hive_metastore_config", "id", b"id", "labels", b"labels", "location", b"location", "maintenance_window", b"maintenance_window", "name", b"name", "network", b"network", "port", b"port", "project", b"project", "release_channel", b"release_channel", "resource_info", b"resource_info", "service_id", b"service_id", "state", b"state", "state_message", b"state_message", "tier", b"tier", "timeouts", b"timeouts", "uid", b"uid"]) -> None: ...

global___DataprocMetastoreService = DataprocMetastoreService

@typing_extensions.final
class DataprocMetastoreServiceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocMetastoreServiceIamBindingXCondition = DataprocMetastoreServiceIamBindingXCondition

@typing_extensions.final
class DataprocMetastoreServiceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    service_id: builtins.str
    @property
    def condition(self) -> global___DataprocMetastoreServiceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service_id: builtins.str = ...,
        condition: global___DataprocMetastoreServiceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service_id", b"service_id"]) -> None: ...

global___DataprocMetastoreServiceIamBinding = DataprocMetastoreServiceIamBinding

@typing_extensions.final
class DataprocMetastoreServiceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___DataprocMetastoreServiceIamMemberXCondition = DataprocMetastoreServiceIamMemberXCondition

@typing_extensions.final
class DataprocMetastoreServiceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    service_id: builtins.str
    @property
    def condition(self) -> global___DataprocMetastoreServiceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        service_id: builtins.str = ...,
        condition: global___DataprocMetastoreServiceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "service_id", b"service_id"]) -> None: ...

global___DataprocMetastoreServiceIamMember = DataprocMetastoreServiceIamMember

@typing_extensions.final
class DataprocMetastoreServiceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    service_id: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        service_id: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "service_id", b"service_id"]) -> None: ...

global___DataprocMetastoreServiceIamPolicy = DataprocMetastoreServiceIamPolicy

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig = DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXHadoopJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    MAIN_JAR_FILE_URI_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    main_class: builtins.str
    main_jar_file_uri: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig: ...
    def __init__(
        self,
        *,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        main_class: builtins.str = ...,
        main_jar_file_uri: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocWorkflowTemplateXJobsXHadoopJobXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_uris", b"archive_uris", "args", b"args", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "main_class", b"main_class", "main_jar_file_uri", b"main_jar_file_uri", "properties", b"properties"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXHadoopJob = DataprocWorkflowTemplateXJobsXHadoopJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXHiveJobXQueryList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        queries: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["queries", b"queries"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXHiveJobXQueryList = DataprocWorkflowTemplateXJobsXHiveJobXQueryList

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXHiveJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ScriptVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTINUE_ON_FAILURE_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    SCRIPT_VARIABLES_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    continue_on_failure: builtins.bool
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def script_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def query_list(self) -> global___DataprocWorkflowTemplateXJobsXHiveJobXQueryList: ...
    def __init__(
        self,
        *,
        continue_on_failure: builtins.bool = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        script_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_list: global___DataprocWorkflowTemplateXJobsXHiveJobXQueryList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["query_list", b"query_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue_on_failure", b"continue_on_failure", "jar_file_uris", b"jar_file_uris", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list", "script_variables", b"script_variables"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXHiveJob = DataprocWorkflowTemplateXJobsXHiveJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig = DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPigJobXQueryList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        queries: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["queries", b"queries"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPigJobXQueryList = DataprocWorkflowTemplateXJobsXPigJobXQueryList

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPigJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ScriptVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTINUE_ON_FAILURE_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    SCRIPT_VARIABLES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    continue_on_failure: builtins.bool
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def script_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig: ...
    @property
    def query_list(self) -> global___DataprocWorkflowTemplateXJobsXPigJobXQueryList: ...
    def __init__(
        self,
        *,
        continue_on_failure: builtins.bool = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        script_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocWorkflowTemplateXJobsXPigJobXLoggingConfig | None = ...,
        query_list: global___DataprocWorkflowTemplateXJobsXPigJobXQueryList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config", "query_list", b"query_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue_on_failure", b"continue_on_failure", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list", "script_variables", b"script_variables"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPigJob = DataprocWorkflowTemplateXJobsXPigJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig = DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPrestoJobXQueryList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        queries: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["queries", b"queries"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPrestoJobXQueryList = DataprocWorkflowTemplateXJobsXPrestoJobXQueryList

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPrestoJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLIENT_TAGS_FIELD_NUMBER: builtins.int
    CONTINUE_ON_FAILURE_FIELD_NUMBER: builtins.int
    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    @property
    def client_tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    continue_on_failure: builtins.bool
    output_format: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def logging_config(self) -> global___DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig: ...
    @property
    def query_list(self) -> global___DataprocWorkflowTemplateXJobsXPrestoJobXQueryList: ...
    def __init__(
        self,
        *,
        client_tags: collections.abc.Iterable[builtins.str] | None = ...,
        continue_on_failure: builtins.bool = ...,
        output_format: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        logging_config: global___DataprocWorkflowTemplateXJobsXPrestoJobXLoggingConfig | None = ...,
        query_list: global___DataprocWorkflowTemplateXJobsXPrestoJobXQueryList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config", "query_list", b"query_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_tags", b"client_tags", "continue_on_failure", b"continue_on_failure", "logging_config", b"logging_config", "output_format", b"output_format", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPrestoJob = DataprocWorkflowTemplateXJobsXPrestoJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig = DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXPysparkJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    MAIN_PYTHON_FILE_URI_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    PYTHON_FILE_URIS_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    main_python_file_uri: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def python_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig: ...
    def __init__(
        self,
        *,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        main_python_file_uri: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        python_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        logging_config: global___DataprocWorkflowTemplateXJobsXPysparkJobXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_uris", b"archive_uris", "args", b"args", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "main_python_file_uri", b"main_python_file_uri", "properties", b"properties", "python_file_uris", b"python_file_uris"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXPysparkJob = DataprocWorkflowTemplateXJobsXPysparkJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXScheduling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_FAILURES_PER_HOUR_FIELD_NUMBER: builtins.int
    MAX_FAILURES_TOTAL_FIELD_NUMBER: builtins.int
    max_failures_per_hour: builtins.float
    max_failures_total: builtins.float
    def __init__(
        self,
        *,
        max_failures_per_hour: builtins.float = ...,
        max_failures_total: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_failures_per_hour", b"max_failures_per_hour", "max_failures_total", b"max_failures_total"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXScheduling = DataprocWorkflowTemplateXJobsXScheduling

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig = DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXSparkJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    MAIN_JAR_FILE_URI_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    main_class: builtins.str
    main_jar_file_uri: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig: ...
    def __init__(
        self,
        *,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        main_class: builtins.str = ...,
        main_jar_file_uri: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocWorkflowTemplateXJobsXSparkJobXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_uris", b"archive_uris", "args", b"args", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "main_class", b"main_class", "main_jar_file_uri", b"main_jar_file_uri", "properties", b"properties"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXSparkJob = DataprocWorkflowTemplateXJobsXSparkJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig = DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXSparkRJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    ARGS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    MAIN_R_FILE_URI_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    main_r_file_uri: builtins.str
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig: ...
    def __init__(
        self,
        *,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        main_r_file_uri: builtins.str = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocWorkflowTemplateXJobsXSparkRJobXLoggingConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["archive_uris", b"archive_uris", "args", b"args", "file_uris", b"file_uris", "logging_config", b"logging_config", "main_r_file_uri", b"main_r_file_uri", "properties", b"properties"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXSparkRJob = DataprocWorkflowTemplateXJobsXSparkRJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DriverLogLevelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DRIVER_LOG_LEVELS_FIELD_NUMBER: builtins.int
    @property
    def driver_log_levels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        driver_log_levels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["driver_log_levels", b"driver_log_levels"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig = DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXSparkSqlJobXQueryList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        queries: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["queries", b"queries"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXSparkSqlJobXQueryList = DataprocWorkflowTemplateXJobsXSparkSqlJobXQueryList

@typing_extensions.final
class DataprocWorkflowTemplateXJobsXSparkSqlJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ScriptVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    SCRIPT_VARIABLES_FIELD_NUMBER: builtins.int
    LOGGING_CONFIG_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    query_file_uri: builtins.str
    @property
    def script_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def logging_config(self) -> global___DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig: ...
    @property
    def query_list(self) -> global___DataprocWorkflowTemplateXJobsXSparkSqlJobXQueryList: ...
    def __init__(
        self,
        *,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        script_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        logging_config: global___DataprocWorkflowTemplateXJobsXSparkSqlJobXLoggingConfig | None = ...,
        query_list: global___DataprocWorkflowTemplateXJobsXSparkSqlJobXQueryList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["logging_config", b"logging_config", "query_list", b"query_list"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jar_file_uris", b"jar_file_uris", "logging_config", b"logging_config", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list", "script_variables", b"script_variables"]) -> None: ...

global___DataprocWorkflowTemplateXJobsXSparkSqlJob = DataprocWorkflowTemplateXJobsXSparkSqlJob

@typing_extensions.final
class DataprocWorkflowTemplateXJobs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LABELS_FIELD_NUMBER: builtins.int
    PREREQUISITE_STEP_IDS_FIELD_NUMBER: builtins.int
    STEP_ID_FIELD_NUMBER: builtins.int
    HADOOP_JOB_FIELD_NUMBER: builtins.int
    HIVE_JOB_FIELD_NUMBER: builtins.int
    PIG_JOB_FIELD_NUMBER: builtins.int
    PRESTO_JOB_FIELD_NUMBER: builtins.int
    PYSPARK_JOB_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    SPARK_JOB_FIELD_NUMBER: builtins.int
    SPARK_R_JOB_FIELD_NUMBER: builtins.int
    SPARK_SQL_JOB_FIELD_NUMBER: builtins.int
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def prerequisite_step_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    step_id: builtins.str
    @property
    def hadoop_job(self) -> global___DataprocWorkflowTemplateXJobsXHadoopJob: ...
    @property
    def hive_job(self) -> global___DataprocWorkflowTemplateXJobsXHiveJob: ...
    @property
    def pig_job(self) -> global___DataprocWorkflowTemplateXJobsXPigJob: ...
    @property
    def presto_job(self) -> global___DataprocWorkflowTemplateXJobsXPrestoJob: ...
    @property
    def pyspark_job(self) -> global___DataprocWorkflowTemplateXJobsXPysparkJob: ...
    @property
    def scheduling(self) -> global___DataprocWorkflowTemplateXJobsXScheduling: ...
    @property
    def spark_job(self) -> global___DataprocWorkflowTemplateXJobsXSparkJob: ...
    @property
    def spark_r_job(self) -> global___DataprocWorkflowTemplateXJobsXSparkRJob: ...
    @property
    def spark_sql_job(self) -> global___DataprocWorkflowTemplateXJobsXSparkSqlJob: ...
    def __init__(
        self,
        *,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        prerequisite_step_ids: collections.abc.Iterable[builtins.str] | None = ...,
        step_id: builtins.str = ...,
        hadoop_job: global___DataprocWorkflowTemplateXJobsXHadoopJob | None = ...,
        hive_job: global___DataprocWorkflowTemplateXJobsXHiveJob | None = ...,
        pig_job: global___DataprocWorkflowTemplateXJobsXPigJob | None = ...,
        presto_job: global___DataprocWorkflowTemplateXJobsXPrestoJob | None = ...,
        pyspark_job: global___DataprocWorkflowTemplateXJobsXPysparkJob | None = ...,
        scheduling: global___DataprocWorkflowTemplateXJobsXScheduling | None = ...,
        spark_job: global___DataprocWorkflowTemplateXJobsXSparkJob | None = ...,
        spark_r_job: global___DataprocWorkflowTemplateXJobsXSparkRJob | None = ...,
        spark_sql_job: global___DataprocWorkflowTemplateXJobsXSparkSqlJob | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hadoop_job", b"hadoop_job", "hive_job", b"hive_job", "pig_job", b"pig_job", "presto_job", b"presto_job", "pyspark_job", b"pyspark_job", "scheduling", b"scheduling", "spark_job", b"spark_job", "spark_r_job", b"spark_r_job", "spark_sql_job", b"spark_sql_job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hadoop_job", b"hadoop_job", "hive_job", b"hive_job", "labels", b"labels", "pig_job", b"pig_job", "prerequisite_step_ids", b"prerequisite_step_ids", "presto_job", b"presto_job", "pyspark_job", b"pyspark_job", "scheduling", b"scheduling", "spark_job", b"spark_job", "spark_r_job", b"spark_r_job", "spark_sql_job", b"spark_sql_job", "step_id", b"step_id"]) -> None: ...

global___DataprocWorkflowTemplateXJobs = DataprocWorkflowTemplateXJobs

@typing_extensions.final
class DataprocWorkflowTemplateXParametersXValidationXRegex(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGEXES_FIELD_NUMBER: builtins.int
    @property
    def regexes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        regexes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["regexes", b"regexes"]) -> None: ...

global___DataprocWorkflowTemplateXParametersXValidationXRegex = DataprocWorkflowTemplateXParametersXValidationXRegex

@typing_extensions.final
class DataprocWorkflowTemplateXParametersXValidationXValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUES_FIELD_NUMBER: builtins.int
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["values", b"values"]) -> None: ...

global___DataprocWorkflowTemplateXParametersXValidationXValues = DataprocWorkflowTemplateXParametersXValidationXValues

@typing_extensions.final
class DataprocWorkflowTemplateXParametersXValidation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGEX_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    @property
    def regex(self) -> global___DataprocWorkflowTemplateXParametersXValidationXRegex: ...
    @property
    def values(self) -> global___DataprocWorkflowTemplateXParametersXValidationXValues: ...
    def __init__(
        self,
        *,
        regex: global___DataprocWorkflowTemplateXParametersXValidationXRegex | None = ...,
        values: global___DataprocWorkflowTemplateXParametersXValidationXValues | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["regex", b"regex", "values", b"values"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["regex", b"regex", "values", b"values"]) -> None: ...

global___DataprocWorkflowTemplateXParametersXValidation = DataprocWorkflowTemplateXParametersXValidation

@typing_extensions.final
class DataprocWorkflowTemplateXParameters(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FIELDS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALIDATION_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def fields(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    @property
    def validation(self) -> global___DataprocWorkflowTemplateXParametersXValidation: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        fields: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        validation: global___DataprocWorkflowTemplateXParametersXValidation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validation", b"validation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "fields", b"fields", "name", b"name", "validation", b"validation"]) -> None: ...

global___DataprocWorkflowTemplateXParameters = DataprocWorkflowTemplateXParameters

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXClusterSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ClusterLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_LABELS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    @property
    def cluster_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    zone: builtins.str
    def __init__(
        self,
        *,
        cluster_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_labels", b"cluster_labels", "zone", b"zone"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXClusterSelector = DataprocWorkflowTemplateXPlacementXClusterSelector

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXAutoscalingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POLICY_FIELD_NUMBER: builtins.int
    policy: builtins.str
    def __init__(
        self,
        *,
        policy: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["policy", b"policy"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXAutoscalingConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXAutoscalingConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GCE_PD_KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    gce_pd_kms_key_name: builtins.str
    def __init__(
        self,
        *,
        gce_pd_kms_key_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gce_pd_kms_key_name", b"gce_pd_kms_key_name"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEncryptionConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEncryptionConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HttpPortsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENABLE_HTTP_PORT_ACCESS_FIELD_NUMBER: builtins.int
    HTTP_PORTS_FIELD_NUMBER: builtins.int
    enable_http_port_access: builtins.bool
    @property
    def http_ports(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        enable_http_port_access: builtins.bool = ...,
        http_ports: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_http_port_access", b"enable_http_port_access", "http_ports", b"http_ports"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXNodeGroupAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_FIELD_NUMBER: builtins.int
    node_group: builtins.str
    def __init__(
        self,
        *,
        node_group: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["node_group", b"node_group"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXNodeGroupAffinity = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXNodeGroupAffinity

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXReservationAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONSUME_RESERVATION_TYPE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    consume_reservation_type: builtins.str
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        consume_reservation_type: builtins.str = ...,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["consume_reservation_type", b"consume_reservation_type", "key", b"key", "values", b"values"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXReservationAffinity = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXReservationAffinity

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    INTERNAL_IP_ONLY_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PRIVATE_IPV6_GOOGLE_ACCESS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_SCOPES_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    NODE_GROUP_AFFINITY_FIELD_NUMBER: builtins.int
    RESERVATION_AFFINITY_FIELD_NUMBER: builtins.int
    internal_ip_only: builtins.bool
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    network: builtins.str
    private_ipv6_google_access: builtins.str
    service_account: builtins.str
    @property
    def service_account_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    subnetwork: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    @property
    def node_group_affinity(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXNodeGroupAffinity: ...
    @property
    def reservation_affinity(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXReservationAffinity: ...
    def __init__(
        self,
        *,
        internal_ip_only: builtins.bool = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network: builtins.str = ...,
        private_ipv6_google_access: builtins.str = ...,
        service_account: builtins.str = ...,
        service_account_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        subnetwork: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
        node_group_affinity: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXNodeGroupAffinity | None = ...,
        reservation_affinity: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfigXReservationAffinity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["node_group_affinity", b"node_group_affinity", "reservation_affinity", b"reservation_affinity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["internal_ip_only", b"internal_ip_only", "metadata", b"metadata", "network", b"network", "node_group_affinity", b"node_group_affinity", "private_ipv6_google_access", b"private_ipv6_google_access", "reservation_affinity", b"reservation_affinity", "service_account", b"service_account", "service_account_scopes", b"service_account_scopes", "subnetwork", b"subnetwork", "tags", b"tags", "zone", b"zone"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXInitializationActions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTABLE_FILE_FIELD_NUMBER: builtins.int
    EXECUTION_TIMEOUT_FIELD_NUMBER: builtins.int
    executable_file: builtins.str
    execution_timeout: builtins.str
    def __init__(
        self,
        *,
        executable_file: builtins.str = ...,
        execution_timeout: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["executable_file", b"executable_file", "execution_timeout", b"execution_timeout"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXInitializationActions = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXInitializationActions

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXLifecycleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_DELETE_TIME_FIELD_NUMBER: builtins.int
    AUTO_DELETE_TTL_FIELD_NUMBER: builtins.int
    IDLE_DELETE_TTL_FIELD_NUMBER: builtins.int
    IDLE_START_TIME_FIELD_NUMBER: builtins.int
    auto_delete_time: builtins.str
    auto_delete_ttl: builtins.str
    idle_delete_ttl: builtins.str
    idle_start_time: builtins.str
    def __init__(
        self,
        *,
        auto_delete_time: builtins.str = ...,
        auto_delete_ttl: builtins.str = ...,
        idle_delete_ttl: builtins.str = ...,
        idle_start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete_time", b"auto_delete_time", "auto_delete_ttl", b"auto_delete_ttl", "idle_delete_ttl", b"idle_delete_ttl", "idle_start_time", b"idle_start_time"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXLifecycleConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXLifecycleConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXAccelerators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_COUNT_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    accelerator_count: builtins.float
    accelerator_type: builtins.str
    def __init__(
        self,
        *,
        accelerator_count: builtins.float = ...,
        accelerator_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_count", b"accelerator_count", "accelerator_type", b"accelerator_type"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXAccelerators = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXAccelerators

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXDiskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    NUM_LOCAL_SSDS_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    num_local_ssds: builtins.float
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        num_local_ssds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "num_local_ssds", b"num_local_ssds"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXDiskConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXDiskConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ManagedGroupConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_FIELD_NUMBER: builtins.int
    INSTANCE_NAMES_FIELD_NUMBER: builtins.int
    IS_PREEMPTIBLE_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MANAGED_GROUP_CONFIG_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NUM_INSTANCES_FIELD_NUMBER: builtins.int
    PREEMPTIBILITY_FIELD_NUMBER: builtins.int
    ACCELERATORS_FIELD_NUMBER: builtins.int
    DISK_CONFIG_FIELD_NUMBER: builtins.int
    image: builtins.str
    @property
    def instance_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_preemptible: builtins.bool
    machine_type: builtins.str
    @property
    def managed_group_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    min_cpu_platform: builtins.str
    num_instances: builtins.float
    preemptibility: builtins.str
    @property
    def accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXAccelerators]: ...
    @property
    def disk_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXDiskConfig: ...
    def __init__(
        self,
        *,
        image: builtins.str = ...,
        instance_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_preemptible: builtins.bool = ...,
        machine_type: builtins.str = ...,
        managed_group_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        min_cpu_platform: builtins.str = ...,
        num_instances: builtins.float = ...,
        preemptibility: builtins.str = ...,
        accelerators: collections.abc.Iterable[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXAccelerators] | None = ...,
        disk_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfigXDiskConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_config", b"disk_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerators", b"accelerators", "disk_config", b"disk_config", "image", b"image", "instance_names", b"instance_names", "is_preemptible", b"is_preemptible", "machine_type", b"machine_type", "managed_group_config", b"managed_group_config", "min_cpu_platform", b"min_cpu_platform", "num_instances", b"num_instances", "preemptibility", b"preemptibility"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXAccelerators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_COUNT_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    accelerator_count: builtins.float
    accelerator_type: builtins.str
    def __init__(
        self,
        *,
        accelerator_count: builtins.float = ...,
        accelerator_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_count", b"accelerator_count", "accelerator_type", b"accelerator_type"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXAccelerators = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXAccelerators

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXDiskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    NUM_LOCAL_SSDS_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    num_local_ssds: builtins.float
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        num_local_ssds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "num_local_ssds", b"num_local_ssds"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXDiskConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXDiskConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ManagedGroupConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_FIELD_NUMBER: builtins.int
    INSTANCE_NAMES_FIELD_NUMBER: builtins.int
    IS_PREEMPTIBLE_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MANAGED_GROUP_CONFIG_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NUM_INSTANCES_FIELD_NUMBER: builtins.int
    PREEMPTIBILITY_FIELD_NUMBER: builtins.int
    ACCELERATORS_FIELD_NUMBER: builtins.int
    DISK_CONFIG_FIELD_NUMBER: builtins.int
    image: builtins.str
    @property
    def instance_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_preemptible: builtins.bool
    machine_type: builtins.str
    @property
    def managed_group_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    min_cpu_platform: builtins.str
    num_instances: builtins.float
    preemptibility: builtins.str
    @property
    def accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXAccelerators]: ...
    @property
    def disk_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXDiskConfig: ...
    def __init__(
        self,
        *,
        image: builtins.str = ...,
        instance_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_preemptible: builtins.bool = ...,
        machine_type: builtins.str = ...,
        managed_group_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        min_cpu_platform: builtins.str = ...,
        num_instances: builtins.float = ...,
        preemptibility: builtins.str = ...,
        accelerators: collections.abc.Iterable[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXAccelerators] | None = ...,
        disk_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfigXDiskConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_config", b"disk_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerators", b"accelerators", "disk_config", b"disk_config", "image", b"image", "instance_names", b"instance_names", "is_preemptible", b"is_preemptible", "machine_type", b"machine_type", "managed_group_config", b"managed_group_config", "min_cpu_platform", b"min_cpu_platform", "num_instances", b"num_instances", "preemptibility", b"preemptibility"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfigXKerberosConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CROSS_REALM_TRUST_ADMIN_SERVER_FIELD_NUMBER: builtins.int
    CROSS_REALM_TRUST_KDC_FIELD_NUMBER: builtins.int
    CROSS_REALM_TRUST_REALM_FIELD_NUMBER: builtins.int
    CROSS_REALM_TRUST_SHARED_PASSWORD_FIELD_NUMBER: builtins.int
    ENABLE_KERBEROS_FIELD_NUMBER: builtins.int
    KDC_DB_KEY_FIELD_NUMBER: builtins.int
    KEY_PASSWORD_FIELD_NUMBER: builtins.int
    KEYSTORE_FIELD_NUMBER: builtins.int
    KEYSTORE_PASSWORD_FIELD_NUMBER: builtins.int
    KMS_KEY_FIELD_NUMBER: builtins.int
    REALM_FIELD_NUMBER: builtins.int
    ROOT_PRINCIPAL_PASSWORD_FIELD_NUMBER: builtins.int
    TGT_LIFETIME_HOURS_FIELD_NUMBER: builtins.int
    TRUSTSTORE_FIELD_NUMBER: builtins.int
    TRUSTSTORE_PASSWORD_FIELD_NUMBER: builtins.int
    cross_realm_trust_admin_server: builtins.str
    cross_realm_trust_kdc: builtins.str
    cross_realm_trust_realm: builtins.str
    cross_realm_trust_shared_password: builtins.str
    enable_kerberos: builtins.bool
    kdc_db_key: builtins.str
    key_password: builtins.str
    keystore: builtins.str
    keystore_password: builtins.str
    kms_key: builtins.str
    realm: builtins.str
    root_principal_password: builtins.str
    tgt_lifetime_hours: builtins.float
    truststore: builtins.str
    truststore_password: builtins.str
    def __init__(
        self,
        *,
        cross_realm_trust_admin_server: builtins.str = ...,
        cross_realm_trust_kdc: builtins.str = ...,
        cross_realm_trust_realm: builtins.str = ...,
        cross_realm_trust_shared_password: builtins.str = ...,
        enable_kerberos: builtins.bool = ...,
        kdc_db_key: builtins.str = ...,
        key_password: builtins.str = ...,
        keystore: builtins.str = ...,
        keystore_password: builtins.str = ...,
        kms_key: builtins.str = ...,
        realm: builtins.str = ...,
        root_principal_password: builtins.str = ...,
        tgt_lifetime_hours: builtins.float = ...,
        truststore: builtins.str = ...,
        truststore_password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cross_realm_trust_admin_server", b"cross_realm_trust_admin_server", "cross_realm_trust_kdc", b"cross_realm_trust_kdc", "cross_realm_trust_realm", b"cross_realm_trust_realm", "cross_realm_trust_shared_password", b"cross_realm_trust_shared_password", "enable_kerberos", b"enable_kerberos", "kdc_db_key", b"kdc_db_key", "key_password", b"key_password", "keystore", b"keystore", "keystore_password", b"keystore_password", "kms_key", b"kms_key", "realm", b"realm", "root_principal_password", b"root_principal_password", "tgt_lifetime_hours", b"tgt_lifetime_hours", "truststore", b"truststore", "truststore_password", b"truststore_password"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfigXKerberosConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfigXKerberosConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KERBEROS_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def kerberos_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfigXKerberosConfig: ...
    def __init__(
        self,
        *,
        kerberos_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfigXKerberosConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kerberos_config", b"kerberos_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["kerberos_config", b"kerberos_config"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_VERSION_FIELD_NUMBER: builtins.int
    OPTIONAL_COMPONENTS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    image_version: builtins.str
    @property
    def optional_components(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        image_version: builtins.str = ...,
        optional_components: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_version", b"image_version", "optional_components", b"optional_components", "properties", b"properties"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXAccelerators(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCELERATOR_COUNT_FIELD_NUMBER: builtins.int
    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    accelerator_count: builtins.float
    accelerator_type: builtins.str
    def __init__(
        self,
        *,
        accelerator_count: builtins.float = ...,
        accelerator_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_count", b"accelerator_count", "accelerator_type", b"accelerator_type"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXAccelerators = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXAccelerators

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXDiskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOOT_DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    BOOT_DISK_TYPE_FIELD_NUMBER: builtins.int
    NUM_LOCAL_SSDS_FIELD_NUMBER: builtins.int
    boot_disk_size_gb: builtins.float
    boot_disk_type: builtins.str
    num_local_ssds: builtins.float
    def __init__(
        self,
        *,
        boot_disk_size_gb: builtins.float = ...,
        boot_disk_type: builtins.str = ...,
        num_local_ssds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["boot_disk_size_gb", b"boot_disk_size_gb", "boot_disk_type", b"boot_disk_type", "num_local_ssds", b"num_local_ssds"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXDiskConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXDiskConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ManagedGroupConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_FIELD_NUMBER: builtins.int
    INSTANCE_NAMES_FIELD_NUMBER: builtins.int
    IS_PREEMPTIBLE_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    MANAGED_GROUP_CONFIG_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NUM_INSTANCES_FIELD_NUMBER: builtins.int
    PREEMPTIBILITY_FIELD_NUMBER: builtins.int
    ACCELERATORS_FIELD_NUMBER: builtins.int
    DISK_CONFIG_FIELD_NUMBER: builtins.int
    image: builtins.str
    @property
    def instance_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_preemptible: builtins.bool
    machine_type: builtins.str
    @property
    def managed_group_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    min_cpu_platform: builtins.str
    num_instances: builtins.float
    preemptibility: builtins.str
    @property
    def accelerators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXAccelerators]: ...
    @property
    def disk_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXDiskConfig: ...
    def __init__(
        self,
        *,
        image: builtins.str = ...,
        instance_names: collections.abc.Iterable[builtins.str] | None = ...,
        is_preemptible: builtins.bool = ...,
        machine_type: builtins.str = ...,
        managed_group_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        min_cpu_platform: builtins.str = ...,
        num_instances: builtins.float = ...,
        preemptibility: builtins.str = ...,
        accelerators: collections.abc.Iterable[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXAccelerators] | None = ...,
        disk_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfigXDiskConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_config", b"disk_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerators", b"accelerators", "disk_config", b"disk_config", "image", b"image", "instance_names", b"instance_names", "is_preemptible", b"is_preemptible", "machine_type", b"machine_type", "managed_group_config", b"managed_group_config", "min_cpu_platform", b"min_cpu_platform", "num_instances", b"num_instances", "preemptibility", b"preemptibility"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedClusterXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STAGING_BUCKET_FIELD_NUMBER: builtins.int
    TEMP_BUCKET_FIELD_NUMBER: builtins.int
    AUTOSCALING_CONFIG_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    ENDPOINT_CONFIG_FIELD_NUMBER: builtins.int
    GCE_CLUSTER_CONFIG_FIELD_NUMBER: builtins.int
    INITIALIZATION_ACTIONS_FIELD_NUMBER: builtins.int
    LIFECYCLE_CONFIG_FIELD_NUMBER: builtins.int
    MASTER_CONFIG_FIELD_NUMBER: builtins.int
    SECONDARY_WORKER_CONFIG_FIELD_NUMBER: builtins.int
    SECURITY_CONFIG_FIELD_NUMBER: builtins.int
    SOFTWARE_CONFIG_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    staging_bucket: builtins.str
    temp_bucket: builtins.str
    @property
    def autoscaling_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXAutoscalingConfig: ...
    @property
    def encryption_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEncryptionConfig: ...
    @property
    def endpoint_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig: ...
    @property
    def gce_cluster_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig: ...
    @property
    def initialization_actions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXInitializationActions]: ...
    @property
    def lifecycle_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXLifecycleConfig: ...
    @property
    def master_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig: ...
    @property
    def secondary_worker_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig: ...
    @property
    def security_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfig: ...
    @property
    def software_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig: ...
    @property
    def worker_config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig: ...
    def __init__(
        self,
        *,
        staging_bucket: builtins.str = ...,
        temp_bucket: builtins.str = ...,
        autoscaling_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXAutoscalingConfig | None = ...,
        encryption_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEncryptionConfig | None = ...,
        endpoint_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXEndpointConfig | None = ...,
        gce_cluster_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXGceClusterConfig | None = ...,
        initialization_actions: collections.abc.Iterable[global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXInitializationActions] | None = ...,
        lifecycle_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXLifecycleConfig | None = ...,
        master_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXMasterConfig | None = ...,
        secondary_worker_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecondaryWorkerConfig | None = ...,
        security_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSecurityConfig | None = ...,
        software_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXSoftwareConfig | None = ...,
        worker_config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfigXWorkerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config", "encryption_config", b"encryption_config", "endpoint_config", b"endpoint_config", "gce_cluster_config", b"gce_cluster_config", "lifecycle_config", b"lifecycle_config", "master_config", b"master_config", "secondary_worker_config", b"secondary_worker_config", "security_config", b"security_config", "software_config", b"software_config", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_config", b"autoscaling_config", "encryption_config", b"encryption_config", "endpoint_config", b"endpoint_config", "gce_cluster_config", b"gce_cluster_config", "initialization_actions", b"initialization_actions", "lifecycle_config", b"lifecycle_config", "master_config", b"master_config", "secondary_worker_config", b"secondary_worker_config", "security_config", b"security_config", "software_config", b"software_config", "staging_bucket", b"staging_bucket", "temp_bucket", b"temp_bucket", "worker_config", b"worker_config"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfig = DataprocWorkflowTemplateXPlacementXManagedClusterXConfig

@typing_extensions.final
class DataprocWorkflowTemplateXPlacementXManagedCluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    cluster_name: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def config(self) -> global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfig: ...
    def __init__(
        self,
        *,
        cluster_name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        config: global___DataprocWorkflowTemplateXPlacementXManagedClusterXConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_name", b"cluster_name", "config", b"config", "labels", b"labels"]) -> None: ...

global___DataprocWorkflowTemplateXPlacementXManagedCluster = DataprocWorkflowTemplateXPlacementXManagedCluster

@typing_extensions.final
class DataprocWorkflowTemplateXPlacement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_SELECTOR_FIELD_NUMBER: builtins.int
    MANAGED_CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def cluster_selector(self) -> global___DataprocWorkflowTemplateXPlacementXClusterSelector: ...
    @property
    def managed_cluster(self) -> global___DataprocWorkflowTemplateXPlacementXManagedCluster: ...
    def __init__(
        self,
        *,
        cluster_selector: global___DataprocWorkflowTemplateXPlacementXClusterSelector | None = ...,
        managed_cluster: global___DataprocWorkflowTemplateXPlacementXManagedCluster | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_selector", b"cluster_selector", "managed_cluster", b"managed_cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_selector", b"cluster_selector", "managed_cluster", b"managed_cluster"]) -> None: ...

global___DataprocWorkflowTemplateXPlacement = DataprocWorkflowTemplateXPlacement

@typing_extensions.final
class DataprocWorkflowTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___DataprocWorkflowTemplateXTimeouts = DataprocWorkflowTemplateXTimeouts

@typing_extensions.final
class DataprocWorkflowTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DAG_TIMEOUT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    JOBS_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PLACEMENT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    dag_timeout: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    update_time: builtins.str
    version: builtins.float
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocWorkflowTemplateXJobs]: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataprocWorkflowTemplateXParameters]: ...
    @property
    def placement(self) -> global___DataprocWorkflowTemplateXPlacement: ...
    @property
    def timeouts(self) -> global___DataprocWorkflowTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        dag_timeout: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        update_time: builtins.str = ...,
        version: builtins.float = ...,
        jobs: collections.abc.Iterable[global___DataprocWorkflowTemplateXJobs] | None = ...,
        parameters: collections.abc.Iterable[global___DataprocWorkflowTemplateXParameters] | None = ...,
        placement: global___DataprocWorkflowTemplateXPlacement | None = ...,
        timeouts: global___DataprocWorkflowTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["placement", b"placement", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "dag_timeout", b"dag_timeout", "id", b"id", "jobs", b"jobs", "labels", b"labels", "location", b"location", "name", b"name", "parameters", b"parameters", "placement", b"placement", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time", "version", b"version"]) -> None: ...

global___DataprocWorkflowTemplate = DataprocWorkflowTemplate
